# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import DashboardUpdatePublicScope, DashboardUpdatePublicType, DashboardWriteScope, DashboardWriteType

__all__ = ["DashboardUpdatePublicScope", "DashboardUpdatePublicType", "DashboardWriteScope", "DashboardWriteType"]
