# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .chat_completion_choice import ChatCompletionChoice
from .usage import Usage


class ChatCompletionResponse(UniversalBaseModel):
    id: typing.Optional[str] = None
    created: typing.Optional[int] = None
    model: typing.Optional[str] = None
    choices: typing.Optional[typing.List[ChatCompletionChoice]] = None
    usage: typing.Optional[Usage] = None
    system_fingerprint: typing.Optional[str] = None
    service_tier: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
